@@ -420,7 +420,11 @@ class Project extends Relational
 
 			if (in_array($path, $deprecated))
 			{
-				$path = 'components/com_projects/site/assets/img/project.png';
+				$path = 'components/com_projects/site/assets/img/projects-large.gif';
+				if ($size == 'thumb')
+				{
+					$path = 'components/com_projects/site/assets/img/project.png';
+				}
 				$rootPath = PATH_CORE;
 			}
 			else
